@@ -1,13 +1,18 @@
 package Bible::OBML;
+# ABSTRACT: Manipulate Google/GMail Tasks
+
+use strict;
+use warnings;
+
 use Moose;
 use Text::Balanced qw( extract_delimited extract_bracketed );
 use Text::Wrap 'wrap';
 use Bible::OBML::Reference;
 use Bible::OBML::HTML;
 
-with 'Throwable';
+our $VERSION = '1.03'; # VERSION
 
-our $VERSION = '1.02';
+with 'Throwable';
 
 has reference => (
     is      => 'ro',
@@ -469,26 +474,25 @@ sub canonicalize {
 __PACKAGE__->meta->make_immutable;
 1;
 
+__END__
+
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
-Bible::OBML - Open Bible Markup Language parser and renderer
+Bible::OBML - Manipulate Google/GMail Tasks
+
+=head1 VERSION
+
+version 1.03
+
+=for markdown [![Build Status](https://travis-ci.org/gryphonshafer/Bible-OBML.svg)](https://travis-ci.org/gryphonshafer/Bible-OBML)
+[![Coverage Status](https://coveralls.io/repos/gryphonshafer/Bible-OBML/badge.png)](https://coveralls.io/r/gryphonshafer/Bible-OBML)
 
 =head1 SYNOPSIS
 
-    my $data_structure    = $self->parse($obml_text_content);
-    my $obml_text_content = $self->render( $data_structure, $skip_wrapping );
-
-    my $content_with_smart_quotes    = $self->smartify($content);
-    my $content_without_smart_quotes = $self->desmartify($smart_content);
-
-    $self->canonicalize( $input_file, $output_file, $skip_wrapping );
-
-    # ...and because re-inventing the wheel is fun...
-    my $file_content = $self->read_file($filename);
-    $self->write_file( $filename, $content );
-
 =head1 DESCRIPTION
 
 This module provides methods that support parsing and rendering Open Bible
@@ -571,6 +575,23 @@ arrayrefs around some number of strings. The "reference" key will always be
 a hashref with 3 keys. The structure of the values inside the arrayrefs of
 "header" and "content" can be (and usually are) nested.
 
+=for test_synopsis my( $obml_text_content, $data_structure, $skip_wrapping, $content, $smart_content );
+
+    use Bible::OBML;
+    my $self = Bible::OBML->new;
+
+    my $data_structure    = $self->parse($obml_text_content);
+    my $obml_text_content = $self->render( $data_structure, $skip_wrapping );
+
+    my $content_with_smart_quotes    = $self->smartify($content);
+    my $content_without_smart_quotes = $self->desmartify($smart_content);
+
+    $self->canonicalize( $input_file, $output_file, $skip_wrapping );
+
+    # ...and because re-inventing the wheel is fun...
+    my $file_content = $self->read_file($filename);
+    $self->write_file( $filename, $content );
+
 =head1 METHODS
 
 =head2 parse
@@ -642,22 +663,47 @@ instance of L<Bible::OBML::HTML>.
 
 L<Bible::OBML::Reference>, L<Bible::OBML::HTML>.
 
-You can also look for information at:
+You can also look for additional information at:
 
-    GitHub: https://github.com/gryphonshafer/Bible-OBML
-    AnnoCPAN: http://annocpan.org/dist/Bible-OBML
-    CPAN Ratings: http://cpanratings.perl.org/m/Bible-OBML
-    Search CPAN: http://search.cpan.org/dist/Bible-OBML
+=over 4
+
+=item *
+
+L<GitHub|https://github.com/gryphonshafer/Bible-OBML>
+
+=item *
+
+L<CPAN|http://search.cpan.org/dist/Bible-OBML>
+
+=item *
+
+L<MetaCPAN|https://metacpan.org/pod/Bible::OBML>
+
+=item *
+
+L<AnnoCPAN|http://annocpan.org/dist/Bible-OBML>
+
+=item *
+
+L<Travis CI|https://travis-ci.org/gryphonshafer/Bible-OBML>
+
+=item *
+
+L<Coveralls|https://coveralls.io/r/gryphonshafer/Bible-OBML>
+
+=back
+
+=for Pod::Coverage BUILD is_authed json passwd ua user
 
 =head1 AUTHOR
 
-Gryphon Shafer E<lt>gryphon@cpan.orgE<gt>.
+Gryphon Shafer <gryphon@cpan.org>
 
-    code('Perl') || die;
+=head1 COPYRIGHT AND LICENSE
 
-=head1 LICENSE
+This software is copyright (c) 2015 by Gryphon Shafer.
 
-This library is free software; you can redistribute it and/or modify
-it under the same terms as Perl itself.
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
 
 =cut
