@@ -1,11 +1,16 @@
 package Bible::OBML::HTML;
+# ABSTRACT: Manipulate Google/GMail Tasks
+
+use strict;
+use warnings;
+
 use Moose;
 use Template;
 use Bible::OBML;
 
-with 'Throwable';
+our $VERSION = '1.03'; # VERSION
 
-our $VERSION = '1.02';
+with 'Throwable';
 
 has obml => ( is => 'ro', isa => 'Bible::OBML', default => sub { Bible::OBML->new } );
 
@@ -208,22 +213,22 @@ sub _html {
 __PACKAGE__->meta->make_immutable;
 1;
 
+__END__
+
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
-Bible::OBML::HTML - Render OBML as HTML
+Bible::OBML::HTML - Manipulate Google/GMail Tasks
+
+=head1 VERSION
+
+version 1.03
 
 =head1 SYNOPSIS
 
-    $self->from_obml($obml);
-    $self->from_file($filename);
-    $self->from_data($data);
-
-    $self->from_obml( $obml,     $skip_smartify );
-    $self->from_file( $filename, $skip_smartify );
-    $self->from_data( $data,     $skip_smartify );
-
 =head1 DESCRIPTION
 
 This module renders a reasonably reusable HTML block from OBML in either text,
@@ -235,6 +240,19 @@ The intent here is that if you have OBML and need to view it in some nicer form,
 like on a web site, you can use this module's methods to generate a core block
 of HTML, which you'd then wrap with whatever HTML wrapper and CSS you'd like.
 
+=for test_synopsis my( $obml, $filename, $data, $skyp_smartify );
+
+    use Bible::OBML::HTML;
+    my $self = Bible::OBML::HTML->new;
+
+    $self->from_obml($obml);
+    $self->from_file($filename);
+    $self->from_data($data);
+
+    $self->from_obml( $obml,     $skip_smartify );
+    $self->from_file( $filename, $skip_smartify );
+    $self->from_data( $data,     $skip_smartify );
+
 =head1 METHODS
 
 =head2 from_obml
@@ -283,22 +301,47 @@ instance of L<Bible::OBML>.
 
 L<Bible::OBML>, L<Bible::OBML::Reference>.
 
-You can also look for information at:
+You can also look for additional information at:
 
-    GitHub: https://github.com/gryphonshafer/Bible-OBML
-    AnnoCPAN: http://annocpan.org/dist/Bible-OBML
-    CPAN Ratings: http://cpanratings.perl.org/m/Bible-OBML
-    Search CPAN: http://search.cpan.org/dist/Bible-OBML
+=over 4
+
+=item *
+
+L<GitHub|https://github.com/gryphonshafer/Bible-OBML>
+
+=item *
+
+L<CPAN|http://search.cpan.org/dist/Bible-OBML>
+
+=item *
+
+L<MetaCPAN|https://metacpan.org/pod/Bible::OBML>
+
+=item *
+
+L<AnnoCPAN|http://annocpan.org/dist/Bible-OBML>
+
+=item *
+
+L<Travis CI|https://travis-ci.org/gryphonshafer/Bible-OBML>
+
+=item *
+
+L<Coveralls|https://coveralls.io/r/gryphonshafer/Bible-OBML>
+
+=back
+
+=for Pod::Coverage BUILD is_authed json passwd ua user
 
 =head1 AUTHOR
 
-Gryphon Shafer E<lt>gryphon@cpan.orgE<gt>.
+Gryphon Shafer <gryphon@cpan.org>
 
-    code('Perl') || die;
+=head1 COPYRIGHT AND LICENSE
 
-=head1 LICENSE
+This software is copyright (c) 2015 by Gryphon Shafer.
 
-This library is free software; you can redistribute it and/or modify
-it under the same terms as Perl itself.
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
 
 =cut
