@@ -1,10 +1,15 @@
 package Bible::OBML::Reference;
+# ABSTRACT: Manipulate Google/GMail Tasks
+
+use strict;
+use warnings;
+
 use Moose;
 use List::MoreUtils 'firstidx';
 
-with 'Throwable';
+our $VERSION = '1.03'; # VERSION
 
-our $VERSION = '1.02';
+with 'Throwable';
 
 has bible => ( is => 'ro', isa => 'ArrayRef[ArrayRef[Str]]', default => sub { [
     [ 'Genesis', 'Ge', 'Gen' ],
@@ -98,14 +103,16 @@ has bible => ( is => 'ro', isa => 'ArrayRef[ArrayRef[Str]]', default => sub { [
     sub books {
         my ( $self, $book ) = @_;
         return @books unless ($book);
-        return $book_lookup{$book} or $self->throw( qq{Failed to find "$book" during book lookup} );
+        return ( $book_lookup{$book} or $self->throw( qq{Failed to find "$book" during book lookup} ) );
     }
 
     sub acronyms {
         my ( $self, $acronym ) = @_;
         return @acronyms unless ($acronym);
-        return $acronym_lookup{$acronym}
-            or $self->throw( qq{Failed to find "$acronym" during acronym lookup} );
+        return (
+            $acronym_lookup{$acronym}
+            or $self->throw( qq{Failed to find "$acronym" during acronym lookup} )
+        );
     }
 }
 
@@ -214,14 +221,25 @@ sub parse {
 __PACKAGE__->meta->make_immutable;
 1;
 
+__END__
+
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
-Bible::OBML::Reference - Simple Bible reference parser
+Bible::OBML::Reference - Manipulate Google/GMail Tasks
+
+=head1 VERSION
+
+version 1.03
 
 =head1 SYNOPSIS
 
+    use Bible::OBML::Reference;
+    my $self = Bible::OBML::Reference->new;
+
     my $ref = $self->parse('Text that includes Romans 2:2-14 and other words');
 
     my @books    = $self->books;
@@ -286,22 +304,47 @@ longer acronym. The books (as arrayrefs) are listed in Bible order. For example:
 
 L<Bible::OBML>.
 
-You can also look for information at:
+You can also look for additional information at:
 
-    GitHub: https://github.com/gryphonshafer/Bible-OBML
-    AnnoCPAN: http://annocpan.org/dist/Bible-OBML
-    CPAN Ratings: http://cpanratings.perl.org/m/Bible-OBML
-    Search CPAN: http://search.cpan.org/dist/Bible-OBML
+=over 4
+
+=item *
+
+L<GitHub|https://github.com/gryphonshafer/Bible-OBML>
+
+=item *
+
+L<CPAN|http://search.cpan.org/dist/Bible-OBML>
+
+=item *
+
+L<MetaCPAN|https://metacpan.org/pod/Bible::OBML>
+
+=item *
+
+L<AnnoCPAN|http://annocpan.org/dist/Bible-OBML>
+
+=item *
+
+L<Travis CI|https://travis-ci.org/gryphonshafer/Bible-OBML>
+
+=item *
+
+L<Coveralls|https://coveralls.io/r/gryphonshafer/Bible-OBML>
+
+=back
+
+=for Pod::Coverage BUILD is_authed json passwd ua user
 
 =head1 AUTHOR
 
-Gryphon Shafer E<lt>gryphon@cpan.orgE<gt>.
+Gryphon Shafer <gryphon@cpan.org>
 
-    code('Perl') || die;
+=head1 COPYRIGHT AND LICENSE
 
-=head1 LICENSE
+This software is copyright (c) 2015 by Gryphon Shafer.
 
-This library is free software; you can redistribute it and/or modify
-it under the same terms as Perl itself.
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
 
 =cut
